"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
/** @jsx jsx */
const core_1 = require("@emotion/core");
const react_1 = require("react");
const getDependenciesKeyFrom_1 = require("../helpers/getDependenciesKeyFrom");
const selectionsOrchestrator_1 = require("../helpers/selectionsOrchestrator");
const Dropdown_1 = require("./Dropdown");
const NothingToSelect_1 = require("./NothingToSelect");
const dependenciesHelper_1 = require("../helpers/dependenciesHelper");
const canDisableClear_1 = require("../helpers/canDisableClear");
exports.MultipleDropdowns = (props) => {
    const [dropdownsOptions, setDropdownsOptions] = react_1.useState({});
    const [dropdownsSelectedOptions, setDropdownsSelectedOptions] = react_1.useState({});
    const [dimensions, setDimensions] = react_1.useState([]);
    const onSelectChange = (selectedValue, label) => {
        const newSelections = Object.assign(Object.assign({}, dropdownsSelectedOptions), { [label]: selectedValue });
        if (selectedValue == null) {
            delete newSelections[label];
        }
        setDropdownsSelectedOptions(newSelections);
        props.onChange(newSelections);
    };
    const cleanupSelections = () => {
        props.onChange(null);
        setDropdownsSelectedOptions({});
    };
    const updateDepencenciesKey = () => {
        props.dependenciesKeyRef.current = getDependenciesKeyFrom_1.getDependenciesKeyFrom(props);
    };
    react_1.useEffect(() => {
        const updateSelections = () => __awaiter(void 0, void 0, void 0, function* () {
            try {
                const _dropdownsOptions = yield selectionsOrchestrator_1.orchestrateSelections(props);
                const _dimensions = Object.keys(_dropdownsOptions);
                setDimensions(_dimensions);
                setDropdownsOptions(_dropdownsOptions);
                if (dependenciesHelper_1.haveDependenciesChanged(props)) {
                    cleanupSelections();
                    updateDepencenciesKey();
                }
                else {
                    setDropdownsSelectedOptions(getCurrentDropdownSelections(props, _dimensions));
                }
            }
            catch (e) {
                console.error('Error', e);
            }
        });
        updateSelections();
    }, [props.newDependenciesKey]);
    if (!dimensions.length) {
        return core_1.jsx(NothingToSelect_1.NothingToSelect, { name: props.field.name });
    }
    return (core_1.jsx("div", { "data-testid": "MULTIPLE_DROPDOWNS" }, dimensions.map((dimension) => {
        const selectedValue = props.value && props.value.get ? props.value.get(dimension) : '';
        return (core_1.jsx(Dropdown_1.Dropdown, { key: dimension, disableClear: canDisableClear_1.canDisableClear(props), onSelectChange: onSelectChange, options: dropdownsOptions[dimension], dimension: dimension, selectedValue: selectedValue }));
    })));
};
const getCurrentDropdownSelections = (props, dimensions) => {
    const currentDropdownSelections = {};
    dimensions.forEach((key) => {
        if (props.value && props.value.get && props.value.get(key)) {
            currentDropdownSelections[key] = props.value.get(key);
        }
    });
    return currentDropdownSelections;
};
//# sourceMappingURL=MultipleDropdowns.js.map