"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const mustache_1 = __importDefault(require("mustache"));
const getMassagedProps = (props) => {
    const { url, mapper, dependencyComponentVariables } = props.field.options || {};
    if (isNullOrEmpty(url))
        throw new Error('Missing { url: "" } required option');
    if (isNullOrEmpty(mapper))
        throw new Error('Missing { mapper: "" } required option');
    const view = getView(props, dependencyComponentVariables);
    const renderedUrl = renderTemplate(url, view);
    const massagedProps = { url: renderedUrl, mapper };
    return massagedProps;
};
exports.getMassagedProps = getMassagedProps;
const isNullOrEmpty = (input) => {
    if (input == null)
        return true;
    if (typeof input === 'string')
        return input.trim().length === 0;
    return true;
};
function getView(props, dependencyComponentVariables) {
    const view = Object.assign({}, props.context.designerState.editingContentModel.data.toJSON(), {
        targeting: props.targeting,
    });
    if (dependencyComponentVariables && dependencyComponentVariables.length) {
        dependencyComponentVariables.forEach((key) => {
            if (props.object.get(key) != null) {
                view[key] = props.object.get(key);
            }
        });
    }
    return view;
}
function renderTemplate(url, view) {
    const parsedTemplateParts = mustache_1.default.parse(url);
    const variablesToReplace = parsedTemplateParts
        .filter((part) => part[0] === 'name')
        .map((part) => part[1]);
    validateTemplateVariables(variablesToReplace, view);
    const renderedUrl = mustache_1.default.render(url, view);
    return renderedUrl;
}
function resolve(path, view, separator = '.') {
    const keys = path.split(separator);
    return keys.reduce((value, key) => { var _a; return (_a = value) === null || _a === void 0 ? void 0 : _a[key]; }, view);
}
function validateTemplateVariables(variablesToReplace, view) {
    let variablesWithError = [];
    variablesToReplace.forEach((variableToReplace) => {
        if (!resolve(variableToReplace, view)) {
            variablesWithError.push(`{{${variableToReplace}}}`);
        }
    });
    if (variablesWithError.length) {
        throw new Error(`Tokens ${variablesWithError.join(', ')} not replaced`);
    }
}
//# sourceMappingURL=dropdownPropsExtractor.js.map